NegIdxVec

Struct NegIdxVec 

pub struct NegIdxVec<T> {
    pub data: Vec<T>,
    /* private fields */
}
A vector that can be indexed with a negative index, like with Python.

use libdiffsitter::neg_idx_vec::NegIdxVec;
let v = NegIdxVec::from(vec![1, 2, 3]);
let last_negative = v[-1];
let last = v[(v.len() - 1).try_into().unwrap()];

A negative index corresponds to an offset from the end of the vector.

Fields

data: Vec<T>

The underlying vector for the negative index vector

Implementations

Source

impl<T> NegIdxVec<T>

pub fn new<F>(len: usize, f: F) -> Self
where F: FnMut() -> T,

Create a negative index vector with a given size.

This will create an internal vector and all offsets will be pegged relative to the size of this vector.

use libdiffsitter::neg_idx_vec::NegIdxVec;
let v: NegIdxVec<usize> = NegIdxVec::new(1, Default::default);
pub fn reserve(&mut self, additional: usize)

Reserve capacity for a number of additional elements.

pub fn reserve_exact(&mut self, additional: usize)

Reserve space for exactly additional elements.

This will not over-allocate.

pub fn capacity(&self) -> usize

Return the total number of elements the vector can hold without requiring another allocation.

pub fn len(&self) -> usize

Get the length of the vector

pub fn is_empty(&self) -> bool

Returns whether the vector is empty.