pub fn tree_sitter_constructor_symbol_name(lang: &str) -> StringExpand description
Generate the method name to load a parser given the name of the language.
“tree-sitter-” will be prepended to the language and any dashes (-) will be converted to underscores (_).
Arguments
- lang: The name of the language that corresponds to the parser. This must be the language name that corresponds to the actual tree-sitter name for the language because it is used to generate the name of the symbol from the shared object library that serves as the constructor.